#!/bin/bash
#
# Made by Gert Hulselmans for Ultimate Boot CD
# http:/www.ultimatebootcd.com/
#
# Last time edited: 12 Apr 2010
#
# This script updates the definition files of ClamAV to the last version.

echo
echo "Update definition files of ClamAV to the last version"
echo '_____________________________________________________'
echo
echo

SCRIPTFILE="$(cd "${0%/*}" 2>/dev/null; echo "$PWD"/"${0##*/}")"
SCRIPTDIR=`dirname "$SCRIPTFILE"`
cd "$SCRIPTDIR"

ls '../../../../ubcd/tools/linux/antivirus/clamav.sh' > /dev/null 2>&1

if [ "$?" -eq "0" ]; then

    CLAMAV_TEMPDIR="/tmp/ubcd-temp/clamav"
    mkdir -p /root/clamav/
    mkdir -p "${CLAMAV_TEMPDIR}/definitions/root/clamav/"

    if [ "$?" -eq "0" ]; then
        cd "$CLAMAV_TEMPDIR"
        CLAMAV_TEMPDIR=`echo "$PWD"`
    
        cd "$SCRIPTDIR"
    
        if [ -f "${CLAMAV_TEMPDIR}/clamav-update.html.old" ]; then
            OLDVERSION_MAIN=`grep "//database.clamav.net/main.cvd" "${CLAMAV_TEMPDIR}/clamav-update.html.old"`
            OLDVERSION_DAILY=`grep "//database.clamav.net/daily.cvd" "${CLAMAV_TEMPDIR}/clamav-update.html.old"`
        else
            OLDVERSION_MAIN='notting'
            OLDVERSION_DAILY='notting'
        fi
    
        wget -O "${CLAMAV_TEMPDIR}/clamav-update.html" 'http://www.clamwin.com/content/view/58/27/'
    
        NEWVERSION_MAIN=`grep "//database.clamav.net/main.cvd" "${CLAMAV_TEMPDIR}/clamav-update.html"`
        NEWVERSION_DAILY=`grep "//database.clamav.net/daily.cvd" "${CLAMAV_TEMPDIR}/clamav-update.html"`
	echo $NEWVERSION_MAIN
	echo $NEWVERSION_DAILY
    
	if [ "${OLDVERSION_DAILY}" = "${NEWVERSION_DAILY}" ]; then
            echo 'No update available.'
        else
            # Save IFS
            SAVED_IFS=$IFS
    
            # Poor man's 'which' command
            prgXZ=''
            IFS=:
            for i in $PATH ; do
                if [ -x "$i/xz" ] ; then
                prgXZ="$i/xz"
                break
                fi
            done

            # Restore IFS
            IFS=$SAVED_IFS
    
            if [ -n "$prgXZ" ]; then
                if [ "${OLDVERSION_MAIN}" != "${NEWVERSION_MAIN}" ]; then
                    echo "Start downloading 'main.cvd' definition file"
                    echo '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~'
                    echo
                    cp -p -f /root/clamav/main.cvd "${CLAMAV_TEMPDIR}/definitions/root/clamav/main.cvd"
                    if [ -f "${CLAMAV_TEMPDIR}/definitions/root/clamav/main.cvd" ]; then
                        OLDVERSION_MAIN_TIME=`stat -c %Y "${CLAMAV_TEMPDIR}/definitions/root/clamav/main.cvd"`
                    else
                        OLDVERSION_MAIN_TIME=0
                    fi
                    wget -N -P "${CLAMAV_TEMPDIR}/definitions/root/clamav/" 'http://database.clamav.net/main.cvd'
                    echo
                    echo 'Download finished.'
                    echo
                    echo


                    if [ -f "${CLAMAV_TEMPDIR}/definitions/root/clamav/main.cvd" ]; then
                        NEWVERSION_MAIN_TIME=`stat -c %Y "${CLAMAV_TEMPDIR}/definitions/root/clamav/main.cvd"`
                    else
                        NEWVERSION_MAIN_TIME=0
                    fi
                    cp -p -f "${CLAMAV_TEMPDIR}/definitions/root/clamav/main.cvd" /root/clamav/
                fi
    
                echo "Start downloading 'daily.cvd' definition file"
                echo '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~'
                echo
                cp -p -f /root/clamav/daily.cvd "${CLAMAV_TEMPDIR}/definitions/root/clamav/daily.cvd"
                if [ -f "${CLAMAV_TEMPDIR}/definitions/root/clamav/daily.cvd" ]; then
                    OLDVERSION_DAILY_TIME=`stat -c %Y "${CLAMAV_TEMPDIR}/definitions/root/clamav/daily.cvd"`
                else
                    OLDVERSION_DAILY_TIME=0
                fi
                wget -N -P "${CLAMAV_TEMPDIR}/definitions/root/clamav/" 'http://database.clamav.net/daily.cvd'
                echo
                echo
                echo 'Download finished.'


                if [ -f "${CLAMAV_TEMPDIR}/definitions/root/clamav/daily.cvd" ]; then
                    NEWVERSION_DAILY_TIME=`stat -c %Y "${CLAMAV_TEMPDIR}/definitions/root/clamav/daily.cvd"`
                else
                    NEWVERSION_DAILY_TIME=0
                fi
                
                cp -p -f "${CLAMAV_TEMPDIR}/definitions/root/clamav/daily.cvd" /root/clamav/

                # Check if main.cvd or daily.cvd have newer timestamp
                if [ $OLDVERSION_MAIN_TIME -lt $NEWVERSION_MAIN_TIME ] || [ $OLDVERSION_DAILY_TIME -lt $NEWVERSION_DAILY_TIME ] ; then
	            # Remove the old 'clamav-definitions.txz' file
	            rm -f './../../../../pmagic/pmodules/clamav-definitions.txz'
	        
	            echo "Make 'clamav-definitions.txz' file"
	            echo '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~'
	        
	            # Compress, the definition files of ClamAV
	            tar -cv -C "${CLAMAV_TEMPDIR}/definitions/" . | "$prgXZ" -z > "./../../../../pmagic/pmodules/clamav-definitions.txz"
	        
	            # Rename 'clamav-update.html' to 'clamav-update.html.old', so the next time this script runs,
	            # $OLDVERSION_MAIN and $OLDVERSION_DAILY get the values of the last downloaded version.
	            mv -f "${CLAMAV_TEMPDIR}/clamav-update.html" "${CLAMAV_TEMPDIR}/clamav-update.html.old"
                fi
            else
                echo "xz was not found, install it and try again."
                echo 'Site: http://tukaani.org/xz/'
            fi
        fi
    else
        echo "ERROR: Couldn't create directory '${CLAMAV_TEMPDIR}' for storing temporary files."
    fi
else
    echo "ERROR: clamav.sh isn't run from inside the extracted UBCD directory:"
    echo '       (./ubcd/tools/linux/antivirus/clamav.sh)'
fi

echo
